/**
 * A brief explanation for "project.json":
 * Here is the content of project.json file, this is the global configuration for your game, you can modify it to customize some behavior.
 * The detail of each field is under it.
 {
    "project_type": "javascript",
    // "project_type" indicate the program language of your project, you can ignore this field

    "debugMode"     : 1,
    // "debugMode" possible values :
    //      0 - No message will be printed.
    //      1 - cc.error, cc.assert, cc.warn, cc.log will print in console.
    //      2 - cc.error, cc.assert, cc.warn will print in console.
    //      3 - cc.error, cc.assert will print in console.
    //      4 - cc.error, cc.assert, cc.warn, cc.log will print on canvas, available only on web.
    //      5 - cc.error, cc.assert, cc.warn will print on canvas, available only on web.
    //      6 - cc.error, cc.assert will print on canvas, available only on web.

    "showFPS"       : true,
    // Left bottom corner fps information will show when "showFPS" equals true, otherwise it will be hide.

    "frameRate"     : 60,
    // "frameRate" set the wanted frame rate for your game, but the real fps depends on your game implementation and the running environment.

    "id"            : "gameCanvas",
    // "gameCanvas" sets the id of your canvas element on the web page, it's useful only on web.

    "renderMode"    : 0,
    // "renderMode" sets the renderer type, only useful on web :
    //      0 - Automatically chosen by engine
    //      1 - Forced to use canvas renderer
    //      2 - Forced to use WebGL renderer, but this will be ignored on mobile browsers

    "engineDir"     : "frameworks/cocos2d-html5/",
    // In debug mode, if you use the whole engine to develop your game, you should specify its relative path with "engineDir",
    // but if you are using a single engine file, you can ignore it.

    "modules"       : ["cocos2d"],
    // "modules" defines which modules you will need in your game, it's useful only on web,
    // using this can greatly reduce your game's resource size, and the cocos console tool can package your game with only the modules you set.
    // For details about modules definitions, you can refer to "../../frameworks/cocos2d-html5/modulesConfig.json".

    "jsList"        : [
    ]
    // "jsList" sets the list of js files in your game.
 }
 *
 */
var gOnAppOpend = false;
var gOpenAppInfoEntity;
//被外部開啟
onOpen = function(queryString){

    cc.log("**** onOpen ****");

    cc.log(queryString);
    var onOpenTable = JSON.parse(queryString);

    if(onOpenTable['errcode'] && onOpenTable['errcode'] == "001") { //sid 失效

        gOnAppOpend = false;
        debugPrint("2");

    }else if(onOpenTable['sid']){

        gOnAppOpend = true;

        gOpenAppInfoEntity = OpenAppInfoEntity.create(onOpenTable);

        var currentScene = cc.director.getRunningScene();
        if (currentScene) {

            //已開啟app
            OpenAppUtils.switchScene(currentScene);
        }else{

            //尚未開啟app
            cc.director.runScene(new AssetsManagerLoaderScene());
        }

    }

};

cc.game.onStart = function () {
    if (!cc.sys.isNative && document.getElementById("cocosLoading")) //If referenced loading.js, please remove it
        document.body.removeChild(document.getElementById("cocosLoading"));

    cc.director.setClearColor(cc.color(0,0,0,0));
    // Pass true to enable retina display, disabled by default to improve performance
    cc.view.enableRetina(true);
    // Adjust viewport meta
    cc.view.adjustViewPort(true);

    CYPluginManager.orientation.portrait();

    // Setup the resolution policy and design resolution size
    cc.view.setDesignResolutionSize(RESOLUTIONSIZE.HEIGHT, RESOLUTIONSIZE.WIDTH, cc.ResolutionPolicy.EXACT_FIT);
    // The game will be resized when browser size change
    cc.view.resizeWithBrowserSize(true);

    //load resources
    cc.LoaderScene.preload(g_resources, function () {

        cc.log("******** onStart ********");

        //外部開啟AIO for android
        var param = CYPluginManager.OpenApp.onOpenUrlParamsCallBack();
        if(param.length>0){
            onOpen(param);
            return;
        }

        //外部開啟app不執行下面流程
        if(gOnAppOpend){
            cc.log("******** gOnAppOpend ********");
            return;
        }
        cc.log("******** switch gDebugModeIs ********");

        switch (gDebugModeIs){
            case DEBUG_MODETYPE.D_DEFAULT:
                cc.director.runScene(new AssetsManagerLoaderScene());
                break;
            case DEBUG_MODETYPE.D_VIDEO_GAME:
                cc.director.runScene(new TestVideoGameScene());
                break;
            case DEBUG_MODETYPE.D_LOTTERY_GAME:
                cc.director.runScene(new TestLotteryScene());
                break;
            case DEBUG_MODETYPE.D_ITALKING:
                cc.director.runScene(new TestItalkingScene());
                break;
            case DEBUG_MODETYPE.D_UNIT_TEST:
                cc.director.runScene(new UnitTestScene());
                break;
            case DEBUG_MODETYPE.D_SLOT_GAME:
                cc.director.runScene(new TestSlotGameScene());
                break;
            case DEBUG_MODETYPE.D_WEB_LOGIN:
                cc.director.runScene(new G2EWebLoginScene());
                break;
            case DEBUG_MODETYPE.D_WEB_TEST:
                var loadCustomGame = function () {

                    cy.loadJsList(cy.path.sdk, "CYPackage.json", function () {
                        cy.loadJsList(cy.path.videoTemplate, "CYPackage.json", function () {
                            cc.loader.loadJs("VideoGameTemplate/",[
                                "/testcases/TestCaseResourceManager.js","/testcases/TestBID.js","src/Common/CYVideoGameSocketManager.js"
                            ], function () {
                                cy.preLoadScene([
                                    {LoadBlock: ["Json"],Res: tcrm.res}
                                ], function () {
                                    cc.director.runScene(new TestScene());
                                    cc.director.setLandscape();
                                });

                            });
                        });

                    });
                };
                loadCustomGame();


                break;
            default:
                // Lester use don't remove it.
                var loadCustomGame = function () {
                    //載入SDK熱更新檔案
                    cy.loadJsList(cy.path.sdk, "CYPackage.json", function () {
                        //載入大廳公版熱更新檔案
                        cy.loadJsList(cy.path.videoTemplateBgm, "CYPackage.json", function () {
                            cy.loadJsList(cy.path.videoTemplate, "CYPackage.json", function () {
                                cy.loadJsList(cy.path.sdk, "CYHTMLPackage.json", function () {
                                    cy.loadJsList(cy.path.platformTemplate, "CYPackage.json", function () {
                                        cc.loader.loadJs(vt.testPath, [
                                            "/testcases/BaseTestScene.js",
                                            "/testcases/modules/RoadMap/RoadMap_Test.js",
                                            "/testcases/TestCaseResourceManager.js",
                                            //"/testcases/modules/SelectSeat/SelectSeat_Test.js",
                                            "/testcases/modules/CountDown/VGTCountDown_Test.js",
                                            //"/testcases/playground.js"
                                        ], function(){
                                            cy.preLoadScene([
                                                {LoadBlock: ["BaseTestScene", "playground"],Res: tcrm.res},
                                                {LoadBlock: ["UltimateGameScene", "Pokers", "VGTCountDownUltimateGame"], Res: vt.res}
                                            ], function () {
                                                // RoadMap
                                                //cy.preLoadScene([
                                                //    {LoadBlock: ["RoadMap"],Res: vt.res}
                                                //], function () {
                                                //    if (cc.sys.isNative) jsb.fileUtils.addSearchPath("VideoGameTemplate/testcases/res");
                                                //    cc.director.runScene(new RoadMapTestScene());
                                                //}, this);
                                                cc.director.runScene(new TestScene());
                                                cc.director.setLandscape();

                                                // BID SelectSeat
                                                //var loadScene  = function(){
                                                //    CustomUpdateUtility.setAllVideoGamePathByGameName("BBBID");
                                                //    cy.loadJsList(cy.path["BBBID"], "CYPackage.json", function () {
                                                //        cy.preLoadScene([
                                                //            {LoadBlock: ["BBBIDHallScene","BBBIDGameScene"],Res: bid.res}
                                                //        ], function () {
                                                //            cy.loadJsList("AllVideoGame/BBBID/", "CYPackage.json", function () {
                                                //                if (cc.sys.isNative) jsb.fileUtils.addSearchPath("VideoGameTemplate/testcases/res");
                                                //                cc.director.runScene(new TestScene());
                                                //            });
                                                //        }, this);
                                                //    });
                                                //};
                                                ////載入大廳公版熱更新檔案
                                                //if (cc.sys.isNative) {
                                                //    cy.loadJsList(cy.path.platformTemplate, "CYPackage.json", function () {
                                                //        loadScene();
                                                //    });
                                                //} else {
                                                //    cy.loadJsList(cy.path.sdk, "CYHTMLPackage.json", function () {
                                                //        cy.loadJsList(cy.path.platformTemplate, "CYPackage.json", function () {
                                                //            loadScene();
                                                //        });
                                                //    });
                                                //}
                                            }, this);
                                        });                                    });
                                });

                            });
                        });
                    });
                };
                loadCustomGame();
        }
    }, this);

    //var scene = new AssetsManagerLoaderScene();
    //scene.run();
    //cc.LoaderScene.preload(g_resources, function () {
    //    cc.director.runScene(TestScene.create());
    //}, this);

};
cc.game.run();
