/**
 * Created by James on 2015/12/17.
 */
/**
 * Created by James on 2015/12/14.
 */

var cy = cy || {};

/**
 * 用來載入JS File
 * @param baseRoot 根目錄
 * @param jsonFile 相對位置的檔案
 * @param callBack 載入完成以後的CallBack Function
 */
cy.loadJsList = function (baseRoot, jsonFile, callBack) {
    cy._loaderJsList = cy._loaderJsList || [];
    if (cy._loaderJsList.indexOf(baseRoot + jsonFile) > 0) {
        callBack();
        return;
    }
    cy._loaderJsList.push(baseRoot + jsonFile);
    var syncHandler = function (jsFileList, finishCallBack) {
        if (jsFileList.length != 0) {
            cc.loader.loadJs(baseRoot, jsFileList[0], function () {
                jsFileList.splice(0, 1);
                syncHandler(jsFileList, finishCallBack);
            });
        } else {
            finishCallBack();
        }
    };
    cc.loader.loadJson(baseRoot + jsonFile, function (errorCode, jsonData) {
        if (errorCode == null) {
            if (jsonData["isSync"]) {
                syncHandler(jsonData['jsList'], callBack);
            } else {
                cc.loader.loadJs(baseRoot, jsonData['jsList'], callBack);
            }
        }
    });
};

/**
 * 批次載入圖檔的方法(Notice: Res裡面必須要有 Res, LoadBlock 兩個欄位，LoadBlock裡面若有繼承可加上 ParentRes 的欄位)
 * @param resources 提供LoadBlock 跟Res 欄位的物件
 * @param cb 載入完成的回呼函數
 * @param target
 * @example
 *      cy.preLoadScene([
 *          {LoadBlock: ["LoginScene"], Res:project.res}
 *      ], function() {
 *      }, target)
 */

cy.preLoadScene = function (resources, cb, target) {
    cc.assert(Array.isArray(resources), "Resources should be a Array");
    if (cc.sys.isNative) {
        cb();
        return;
    }

    var syncHandler = function (resObject, finishCallBack) {
        if (resObject.length != 0) {
            var resList = [];
            var otherResList = [];
            var resFile = resObject[0].Res;
            var resBlock = resObject[0].LoadBlock;
            cc.assert(typeof resBlock !== "undefined", "Need to define \"LoadBlock\"");
            for (var j in resBlock) {
                var otherResourceLoad = function (loadBlockName, res) {
                    var others = [];
                    loadResource(loadBlockName, res, others);
                    var index = otherResList.map(function(e) { return e.otherModuleRes; }).indexOf(res);
                    if (index != -1) {
                        otherResList[index].otherModuleList = otherResList[index].otherModuleList.concat(others);
                    } else {
                        otherResList.push({otherModuleList: others, otherModuleRes: res});
                    }

                };
                var loadResource = function (loadBlockName, res, finalList) {
                    if (res[loadBlockName]) {
                        if (res[loadBlockName]["ParentRes"]) {
                            var parentName = res[loadBlockName]["ParentRes"];
                            loadResource(parentName, res, finalList);
                        }
                        if (res[loadBlockName]["Module"]) {
                            if (res[loadBlockName]["Module"]["self"]) {
                                var moduleList = res[loadBlockName]["Module"]["self"];
                                for (var i in moduleList) {
                                    loadResource(moduleList[i], res, finalList);
                                }
                            }
                            if (res[loadBlockName]["Module"]["other"]) {
                                var otherModuleList = res[loadBlockName]["Module"]["other"];
                                for (var i in otherModuleList) {
                                    var otherModule = otherModuleList[i];
                                    cc.assert(otherModule["res"], "Should setup 'res' key");
                                    cc.assert(otherModule["list"], "Should setup 'list' key");
                                    for (var j in otherModule["list"]) {
                                        var moduleName = otherModule["list"][j];
                                        otherResourceLoad(moduleName, otherModule["res"]);
                                    }

                                }
                            }
                        }
                    }

                    cy._getParsingList(res[loadBlockName], finalList);

                };
                loadResource(resBlock[j], resFile, resList);
            }
            if (otherResList.length != 0) {
                var loadOtherRes = function (res) {
                    if (res.length != 0) {
                        var otherModuleList = res[0]["otherModuleList"];
                        var otherModuleRes = res[0]["otherModuleRes"];
                        cc.LoaderScene.preload(otherModuleList, function () {
                            res.splice(0, 1);
                            loadOtherRes(res);
                        }, this);
                    } else {
                        cc.LoaderScene.preload(resList, function () {
                            resObject.splice(0, 1);
                            syncHandler(resObject, finishCallBack);
                        }, this);
                    }
                };
                loadOtherRes(otherResList);
            } else {
                cc.LoaderScene.preload(resList, function () {
                    resObject.splice(0, 1);
                    syncHandler(resObject, finishCallBack);
                }, this);
            }

        } else {
            finishCallBack(target);
        }
    };
    syncHandler(resources, cb);
};

/**
 * 遞迴樹狀路徑下的資料，將取得的STRING載入resList
 * @param resourceTable
 * @param resList
 * @private
 */
cy._getParsingList = function (resourceTable, resList) {
    for (var key in resourceTable) {
        if (key != "Module" && key != "ParentRes") {
            var value = resourceTable[key];
            var reg = /(\.(jpe?g|png|gif|bmp|json|plist|fnt|atlas)$)/i;
            var reg2 = /(Scene3D.json)$/;
            if (typeof value === "string" && value.length > 0 ) {
                if (reg.test(value) && !reg2.test(value) && value.indexOf("#") == -1) {
                    resList.push(value);
                }
            } else if (cc.Color && value instanceof  cc.Color) {
                //Do Nothing, the property is cc.color
            } else {
                cy._getParsingList(value, resList);
            }
        }
    }
};