/**
 * Created by kingsley_lee on 15/12/18.
 */

/**
 *
 * @param manifestPath 熱更新manifest路徑
 * @param destinationFolder 熱更新檔案資料夾
 * @constructor
 */

var PLATFORM_ASSTES_MANAGER = {
    ERROR_NO_LOCAL_MANIFEST : "168101",
    ERROR_DOWNLOAD_MANIFEST : "168102",
    ERROR_PARSE_MANIFEST : "168103",
    UPDATE_FAILED : "168104",
    ERROR_DECOMPRESS : "168105",
    ERROR_UPDATING : "168106"

}

var PlatformAsstesManager = function(manifestPath,destinationFolder){

    var self = this;
    this._failCount = 0;
    this._retryCount = 3;

    var _init = function(){
        self._downloadPath = ASSTES_DOWNLOADPATH + destinationFolder;
        self._manifestPath = manifestPath;

        cc.log("[PlatformAsstesManager]Asstes DownloadPath : " + self._downloadPath);
        cc.log("[PlatformAsstesManager]ManifestPath : " + self._manifestPath);
    }

    _init();

    /**
     *
     * @param delegate must be implement
     * onError(errCode)
     * onProgress(percent)
     * onFinished
     */
    this.update = function(delegate){

        var isExists = jsb.fileUtils.isFileExist(this._manifestPath);
        if(!isExists){
            cc.log(this._manifestPath + " No local manifest file found error.");
            if(delegate){
                delegate.onError(PLATFORM_ASSTES_MANAGER.ERROR_NO_LOCAL_MANIFEST);
            }
            return;
        }

        var self = this;
        this._am = new jsb.AssetsManager(this._manifestPath, this._downloadPath);
        this._am.retain();
        var listener = new jsb.EventListenerAssetsManager(this._am, function (event) {

            var onVersion = function(){
                var remoteManifest = self._am.getRemoteManifest();
                if(remoteManifest){
                    cc.log("onVersion " + remoteManifest.getVersion());

                    if(delegate && delegate.onVersion){
                        delegate.onVersion(remoteManifest.getVersion());
                    }
                }
            };

            switch (event.getEventCode()) {
                case jsb.EventAssetsManager.ERROR_NO_LOCAL_MANIFEST:
                    cc.log("[PlatformAsstesManager]No local manifest file found, skip assets update.");
                    if(delegate){
                        delegate.onError(PLATFORM_ASSTES_MANAGER.ERROR_NO_LOCAL_MANIFEST);
                    }
                    break;
                case jsb.EventAssetsManager.UPDATE_PROGRESSION:
                    var percent = event.getPercent();
                    var percentByFile = event.getPercentByFile();
                    cc.log("[PlatformAsstesManager]" + percent + "%");
                    var msg = event.getMessage();
                    if (msg) {
                        cc.log("[PlatformAsstesManager]" + msg);
                    }
                    if(delegate){
                        delegate.onProgress(percent);
                    }

                    onVersion();

                    break;
                case jsb.EventAssetsManager.ERROR_DOWNLOAD_MANIFEST:
                    if(delegate){
                        delegate.onError(PLATFORM_ASSTES_MANAGER.ERROR_DOWNLOAD_MANIFEST);
                    }
                    break;
                case jsb.EventAssetsManager.ERROR_PARSE_MANIFEST:
                    cc.log("[PlatformAsstesManager]Fail to download manifest file, update skipped.");
                    if(delegate){
                        delegate.onError(PLATFORM_ASSTES_MANAGER.ERROR_PARSE_MANIFEST);
                    }
                    break;
                case jsb.EventAssetsManager.ALREADY_UP_TO_DATE:
                case jsb.EventAssetsManager.UPDATE_FINISHED:
                    cc.log("[PlatformAsstesManager]Update finished.");

                    onVersion();

                    if(delegate){
                        delegate.onFinished();
                    }
                    break;
                case jsb.EventAssetsManager.UPDATE_FAILED:
                    cc.log("[PlatformAsstesManager]Update failed. " + event.getMessage());
                    self._failCount++;
                    if (self._failCount < self._retryCount) {
                        self._am.downloadFailedAssets();
                    } else {
                        cc.log("[PlatformAsstesManager]Reach maximum fail count, exit update process");
                        self._failCount = 0;
                        if(delegate){
                            delegate.onError(PLATFORM_ASSTES_MANAGER.UPDATE_FAILED);
                        }
                    }
                    break;
                case jsb.EventAssetsManager.ERROR_UPDATING:
                    cc.log("[PlatformAsstesManager]Asset update error: " + event.getAssetId() + ", " + event.getMessage());
                    //cc.log("[PlatformAsstesManager]PackageUrl :" + self._am.getRemoteManifest().getPackageUrl());
                    //cc.log("[PlatformAsstesManager]ManifestFileUrl :" + self._am.getRemoteManifest().getManifestFileUrl());
                    //cc.log("[PlatformAsstesManager]VersionFileUrl :" + self._am.getRemoteManifest().getVersionFileUrl());
                    if(delegate){
                        delegate.onError(PLATFORM_ASSTES_MANAGER.ERROR_UPDATING);
                    }

                    break;
                case jsb.EventAssetsManager.ERROR_DECOMPRESS:
                    cc.log(event.getMessage());
                    if(delegate){
                        delegate.onError(PLATFORM_ASSTES_MANAGER.ERROR_DECOMPRESS);
                    }
                    break;
                case jsb.EventAssetsManager.ASSET_UPDATED:
                    onVersion();
                    break;
                default:
                    break;
            }
        });
        cc.eventManager.addListener(listener, 1);
        this._am.update();
    }

    this.release = function(){
        if (cc.sys.isNative) {
            this._am.release();
        }
    }
}